==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-compute-instance-template.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleComputeInstanceTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#filter DataGoogleComputeInstanceTemplate#filter}.
     *
     * @stability stable
     */
    readonly filter?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#most_recent DataGoogleComputeInstanceTemplate#most_recent}.
     *
     * @stability stable
     */
    readonly mostRecent?: boolean | cdktf.IResolvable;
    /**
     * The name of the instance template. If you leave this blank, Terraform will auto-generate a unique name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#name DataGoogleComputeInstanceTemplate#name}
     *
     * @stability stable
     */
    readonly name?: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#project DataGoogleComputeInstanceTemplate#project}
     *
     * @stability stable
     */
    readonly project: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateAdvancedMachineFeatures extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enableNestedVirtualization(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get threadsPerCore(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateConfidentialInstanceConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enableConfidentialCompute(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateDiskDiskEncryptionKey extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get kmsKeySelfLink(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateDisk extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get autoDelete(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get boot(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get deviceName(): string;
    /**
     * @stability stable
     */
    get diskEncryptionKey(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get diskName(): string;
    /**
     * @stability stable
     */
    get diskSizeGb(): number;
    /**
     * @stability stable
     */
    get diskType(): string;
    /**
     * @stability stable
     */
    get interface(): string;
    /**
     * @stability stable
     */
    get labels(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get mode(): string;
    /**
     * @stability stable
     */
    get resourcePolicies(): string[];
    /**
     * @stability stable
     */
    get source(): string;
    /**
     * @stability stable
     */
    get sourceImage(): string;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateGuestAccelerator extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get count(): number;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceAccessConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get natIp(): string;
    /**
     * @stability stable
     */
    get networkTier(): string;
    /**
     * @stability stable
     */
    get publicPtrDomainName(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceAliasIpRange extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get ipCidrRange(): string;
    /**
     * @stability stable
     */
    get subnetworkRangeName(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceIpv6AccessConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get externalIpv6(): string;
    /**
     * @stability stable
     */
    get externalIpv6PrefixLength(): string;
    /**
     * @stability stable
     */
    get networkTier(): string;
    /**
     * @stability stable
     */
    get publicPtrDomainName(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateNetworkInterface extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get accessConfig(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get aliasIpRange(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get ipv6AccessConfig(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get ipv6AccessType(): string;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    get networkIp(): string;
    /**
     * @stability stable
     */
    get nicType(): string;
    /**
     * @stability stable
     */
    get stackType(): string;
    /**
     * @stability stable
     */
    get subnetwork(): string;
    /**
     * @stability stable
     */
    get subnetworkProject(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateReservationAffinitySpecificReservation extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    get values(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateReservationAffinity extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get specificReservation(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get type(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateSchedulingNodeAffinities extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get key(): string;
    /**
     * @stability stable
     */
    get operator(): string;
    /**
     * @stability stable
     */
    get values(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateScheduling extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get automaticRestart(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get minNodeCpus(): number;
    /**
     * @stability stable
     */
    get nodeAffinities(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get onHostMaintenance(): string;
    /**
     * @stability stable
     */
    get preemptible(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateServiceAccount extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get email(): string;
    /**
     * @stability stable
     */
    get scopes(): string[];
}
/**
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplateShieldedInstanceConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get enableIntegrityMonitoring(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get enableSecureBoot(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get enableVtpm(): cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template google_compute_instance_template}.
 *
 * @stability stable
 */
export declare class DataGoogleComputeInstanceTemplate extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template google_compute_instance_template} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleComputeInstanceTemplateConfig);
    /**
     * @stability stable
     */
    advancedMachineFeatures(index: string): DataGoogleComputeInstanceTemplateAdvancedMachineFeatures;
    /**
     * @stability stable
     */
    get canIpForward(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    confidentialInstanceConfig(index: string): DataGoogleComputeInstanceTemplateConfidentialInstanceConfig;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    disk(index: string): DataGoogleComputeInstanceTemplateDisk;
    /**
     * @stability stable
     */
    get enableDisplay(): cdktf.IResolvable;
    private _filter?;
    /**
     * @stability stable
     */
    get filter(): string;
    /**
     * @stability stable
     */
    set filter(value: string);
    /**
     * @stability stable
     */
    resetFilter(): void;
    /**
     * @stability stable
     */
    get filterInput(): string | undefined;
    /**
     * @stability stable
     */
    guestAccelerator(index: string): DataGoogleComputeInstanceTemplateGuestAccelerator;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    get instanceDescription(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get machineType(): string;
    /**
     * @stability stable
     */
    metadata(key: string): string | cdktf.IResolvable;
    /**
     * @stability stable
     */
    get metadataFingerprint(): string;
    /**
     * @stability stable
     */
    get metadataStartupScript(): string;
    /**
     * @stability stable
     */
    get minCpuPlatform(): string;
    private _mostRecent?;
    /**
     * @stability stable
     */
    get mostRecent(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set mostRecent(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetMostRecent(): void;
    /**
     * @stability stable
     */
    get mostRecentInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    resetName(): void;
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    /**
     * @stability stable
     */
    get namePrefix(): string;
    /**
     * @stability stable
     */
    networkInterface(index: string): DataGoogleComputeInstanceTemplateNetworkInterface;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    reservationAffinity(index: string): DataGoogleComputeInstanceTemplateReservationAffinity;
    /**
     * @stability stable
     */
    scheduling(index: string): DataGoogleComputeInstanceTemplateScheduling;
    /**
     * @stability stable
     */
    get selfLink(): string;
    /**
     * @stability stable
     */
    serviceAccount(index: string): DataGoogleComputeInstanceTemplateServiceAccount;
    /**
     * @stability stable
     */
    shieldedInstanceConfig(index: string): DataGoogleComputeInstanceTemplateShieldedInstanceConfig;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    get tagsFingerprint(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.33.tar.gz: package/lib/data-google-compute-instance-template.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComputeInstanceTemplateConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#filter DataGoogleComputeInstanceTemplate#filter}
    */
    readonly filter?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#most_recent DataGoogleComputeInstanceTemplate#most_recent}
    */
    readonly mostRecent?: boolean | cdktf.IResolvable;
    /**
    * The name of the instance template. If you leave this blank, Terraform will auto-generate a unique name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#name DataGoogleComputeInstanceTemplate#name}
    */
    readonly name?: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template#project DataGoogleComputeInstanceTemplate#project}
    */
    readonly project: string;
}
export declare class DataGoogleComputeInstanceTemplateAdvancedMachineFeatures extends cdktf.ComplexComputedList {
    get enableNestedVirtualization(): cdktf.IResolvable;
    get threadsPerCore(): number;
}
export declare class DataGoogleComputeInstanceTemplateConfidentialInstanceConfig extends cdktf.ComplexComputedList {
    get enableConfidentialCompute(): cdktf.IResolvable;
}
export declare class DataGoogleComputeInstanceTemplateDiskDiskEncryptionKey extends cdktf.ComplexComputedList {
    get kmsKeySelfLink(): string;
}
export declare class DataGoogleComputeInstanceTemplateDisk extends cdktf.ComplexComputedList {
    get autoDelete(): cdktf.IResolvable;
    get boot(): cdktf.IResolvable;
    get deviceName(): string;
    get diskEncryptionKey(): cdktf.IResolvable;
    get diskName(): string;
    get diskSizeGb(): number;
    get diskType(): string;
    get interface(): string;
    get labels(): {
        [key: string]: string;
    };
    get mode(): string;
    get resourcePolicies(): string[];
    get source(): string;
    get sourceImage(): string;
    get type(): string;
}
export declare class DataGoogleComputeInstanceTemplateGuestAccelerator extends cdktf.ComplexComputedList {
    get count(): number;
    get type(): string;
}
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceAccessConfig extends cdktf.ComplexComputedList {
    get natIp(): string;
    get networkTier(): string;
    get publicPtrDomainName(): string;
}
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceAliasIpRange extends cdktf.ComplexComputedList {
    get ipCidrRange(): string;
    get subnetworkRangeName(): string;
}
export declare class DataGoogleComputeInstanceTemplateNetworkInterfaceIpv6AccessConfig extends cdktf.ComplexComputedList {
    get externalIpv6(): string;
    get externalIpv6PrefixLength(): string;
    get networkTier(): string;
    get publicPtrDomainName(): string;
}
export declare class DataGoogleComputeInstanceTemplateNetworkInterface extends cdktf.ComplexComputedList {
    get accessConfig(): cdktf.IResolvable;
    get aliasIpRange(): cdktf.IResolvable;
    get ipv6AccessConfig(): cdktf.IResolvable;
    get ipv6AccessType(): string;
    get name(): string;
    get network(): string;
    get networkIp(): string;
    get nicType(): string;
    get stackType(): string;
    get subnetwork(): string;
    get subnetworkProject(): string;
}
export declare class DataGoogleComputeInstanceTemplateReservationAffinitySpecificReservation extends cdktf.ComplexComputedList {
    get key(): string;
    get values(): string[];
}
export declare class DataGoogleComputeInstanceTemplateReservationAffinity extends cdktf.ComplexComputedList {
    get specificReservation(): cdktf.IResolvable;
    get type(): string;
}
export declare class DataGoogleComputeInstanceTemplateSchedulingNodeAffinities extends cdktf.ComplexComputedList {
    get key(): string;
    get operator(): string;
    get values(): string[];
}
export declare class DataGoogleComputeInstanceTemplateScheduling extends cdktf.ComplexComputedList {
    get automaticRestart(): cdktf.IResolvable;
    get minNodeCpus(): number;
    get nodeAffinities(): cdktf.IResolvable;
    get onHostMaintenance(): string;
    get preemptible(): cdktf.IResolvable;
}
export declare class DataGoogleComputeInstanceTemplateServiceAccount extends cdktf.ComplexComputedList {
    get email(): string;
    get scopes(): string[];
}
export declare class DataGoogleComputeInstanceTemplateShieldedInstanceConfig extends cdktf.ComplexComputedList {
    get enableIntegrityMonitoring(): cdktf.IResolvable;
    get enableSecureBoot(): cdktf.IResolvable;
    get enableVtpm(): cdktf.IResolvable;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template google_compute_instance_template}
*/
export declare class DataGoogleComputeInstanceTemplate extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/compute_instance_template google_compute_instance_template} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComputeInstanceTemplateConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleComputeInstanceTemplateConfig);
    advancedMachineFeatures(index: string): DataGoogleComputeInstanceTemplateAdvancedMachineFeatures;
    get canIpForward(): cdktf.IResolvable;
    confidentialInstanceConfig(index: string): DataGoogleComputeInstanceTemplateConfidentialInstanceConfig;
    get description(): string;
    disk(index: string): DataGoogleComputeInstanceTemplateDisk;
    get enableDisplay(): cdktf.IResolvable;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    guestAccelerator(index: string): DataGoogleComputeInstanceTemplateGuestAccelerator;
    get id(): string;
    get instanceDescription(): string;
    labels(key: string): string | cdktf.IResolvable;
    get machineType(): string;
    metadata(key: string): string | cdktf.IResolvable;
    get metadataFingerprint(): string;
    get metadataStartupScript(): string;
    get minCpuPlatform(): string;
    private _mostRecent?;
    get mostRecent(): boolean | cdktf.IResolvable;
    set mostRecent(value: boolean | cdktf.IResolvable);
    resetMostRecent(): void;
    get mostRecentInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    get namePrefix(): string;
    networkInterface(index: string): DataGoogleComputeInstanceTemplateNetworkInterface;
    private _project?;
    get project(): string;
    set project(value: string);
    get projectInput(): string | undefined;
    get region(): string;
    reservationAffinity(index: string): DataGoogleComputeInstanceTemplateReservationAffinity;
    scheduling(index: string): DataGoogleComputeInstanceTemplateScheduling;
    get selfLink(): string;
    serviceAccount(index: string): DataGoogleComputeInstanceTemplateServiceAccount;
    shieldedInstanceConfig(index: string): DataGoogleComputeInstanceTemplateShieldedInstanceConfig;
    get tags(): string[];
    get tagsFingerprint(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
